==> huaweicloudsdkdws-3.0.77-py2.py3-none-any.whl: huaweicloudsdkdws/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DwsClient
from huaweicloudsdkdws.v2.dws_client import DwsClient
from huaweicloudsdkdws.v2.dws_async_client import DwsAsyncClient
# import models into sdk package
from huaweicloudsdkdws.v2.model.cluster import Cluster
from huaweicloudsdkdws.v2.model.cluster_detail import ClusterDetail
from huaweicloudsdkdws.v2.model.cluster_info import ClusterInfo
from huaweicloudsdkdws.v2.model.create_cluster_info import CreateClusterInfo
from huaweicloudsdkdws.v2.model.create_cluster_request import CreateClusterRequest
from huaweicloudsdkdws.v2.model.create_cluster_request_body import CreateClusterRequestBody
from huaweicloudsdkdws.v2.model.create_cluster_response import CreateClusterResponse
from huaweicloudsdkdws.v2.model.create_snapshot_request import CreateSnapshotRequest
from huaweicloudsdkdws.v2.model.create_snapshot_request_body import CreateSnapshotRequestBody
from huaweicloudsdkdws.v2.model.create_snapshot_response import CreateSnapshotResponse
from huaweicloudsdkdws.v2.model.delete_cluster_request import DeleteClusterRequest
from huaweicloudsdkdws.v2.model.delete_cluster_request_body import DeleteClusterRequestBody
from huaweicloudsdkdws.v2.model.delete_cluster_response import DeleteClusterResponse
from huaweicloudsdkdws.v2.model.delete_snapshot_request import DeleteSnapshotRequest
from huaweicloudsdkdws.v2.model.delete_snapshot_response import DeleteSnapshotResponse
from huaweicloudsdkdws.v2.model.detail import Detail
from huaweicloudsdkdws.v2.model.endpoints import Endpoints
from huaweicloudsdkdws.v2.model.failed_reason import FailedReason
from huaweicloudsdkdws.v2.model.list_cluster_details_request import ListClusterDetailsRequest
from huaweicloudsdkdws.v2.model.list_cluster_details_response import ListClusterDetailsResponse
from huaweicloudsdkdws.v2.model.list_clusters_request import ListClustersRequest
from huaweicloudsdkdws.v2.model.list_clusters_response import ListClustersResponse
from huaweicloudsdkdws.v2.model.list_node_types_request import ListNodeTypesRequest
from huaweicloudsdkdws.v2.model.list_node_types_response import ListNodeTypesResponse
from huaweicloudsdkdws.v2.model.list_snapshot_details_request import ListSnapshotDetailsRequest
from huaweicloudsdkdws.v2.model.list_snapshot_details_response import ListSnapshotDetailsResponse
from huaweicloudsdkdws.v2.model.list_snapshots_request import ListSnapshotsRequest
from huaweicloudsdkdws.v2.model.list_snapshots_response import ListSnapshotsResponse
from huaweicloudsdkdws.v2.model.maintain_window import MaintainWindow
from huaweicloudsdkdws.v2.model.node_types import NodeTypes
from huaweicloudsdkdws.v2.model.parameter_group import ParameterGroup
from huaweicloudsdkdws.v2.model.public_endpoints import PublicEndpoints
from huaweicloudsdkdws.v2.model.public_ip import PublicIp
from huaweicloudsdkdws.v2.model.reset_password_request import ResetPasswordRequest
from huaweicloudsdkdws.v2.model.reset_password_request_body import ResetPasswordRequestBody
from huaweicloudsdkdws.v2.model.reset_password_response import ResetPasswordResponse
from huaweicloudsdkdws.v2.model.resize_cluster_request import ResizeClusterRequest
from huaweicloudsdkdws.v2.model.resize_cluster_request_body import ResizeClusterRequestBody
from huaweicloudsdkdws.v2.model.resize_cluster_response import ResizeClusterResponse
from huaweicloudsdkdws.v2.model.resize_info import ResizeInfo
from huaweicloudsdkdws.v2.model.restart_cluster_request import RestartClusterRequest
from huaweicloudsdkdws.v2.model.restart_cluster_request_body import RestartClusterRequestBody
from huaweicloudsdkdws.v2.model.restart_cluster_response import RestartClusterResponse
from huaweicloudsdkdws.v2.model.restore import Restore
from huaweicloudsdkdws.v2.model.restore_cluster_request import RestoreClusterRequest
from huaweicloudsdkdws.v2.model.restore_cluster_request_body import RestoreClusterRequestBody
from huaweicloudsdkdws.v2.model.restore_cluster_response import RestoreClusterResponse
from huaweicloudsdkdws.v2.model.scale_out import ScaleOut
from huaweicloudsdkdws.v2.model.snapsho_detail import SnapshoDetail
from huaweicloudsdkdws.v2.model.snapshot import Snapshot
from huaweicloudsdkdws.v2.model.snapshot_resp import SnapshotResp
from huaweicloudsdkdws.v2.model.snapshots import Snapshots
from huaweicloudsdkdws.v2.model.tags import Tags

==> huaweicloudsdkdws-3.0.87-py2.py3-none-any.whl: huaweicloudsdkdws/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DwsClient
from huaweicloudsdkdws.v2.dws_client import DwsClient
from huaweicloudsdkdws.v2.dws_async_client import DwsAsyncClient
# import models into sdk package
from huaweicloudsdkdws.v2.model.cluster import Cluster
from huaweicloudsdkdws.v2.model.cluster_detail import ClusterDetail
from huaweicloudsdkdws.v2.model.cluster_info import ClusterInfo
from huaweicloudsdkdws.v2.model.create_cluster_info import CreateClusterInfo
from huaweicloudsdkdws.v2.model.create_cluster_request import CreateClusterRequest
from huaweicloudsdkdws.v2.model.create_cluster_request_body import CreateClusterRequestBody
from huaweicloudsdkdws.v2.model.create_cluster_response import CreateClusterResponse
from huaweicloudsdkdws.v2.model.create_snapshot_request import CreateSnapshotRequest
from huaweicloudsdkdws.v2.model.create_snapshot_request_body import CreateSnapshotRequestBody
from huaweicloudsdkdws.v2.model.create_snapshot_response import CreateSnapshotResponse
from huaweicloudsdkdws.v2.model.delete_cluster_request import DeleteClusterRequest
from huaweicloudsdkdws.v2.model.delete_cluster_request_body import DeleteClusterRequestBody
from huaweicloudsdkdws.v2.model.delete_cluster_response import DeleteClusterResponse
from huaweicloudsdkdws.v2.model.delete_snapshot_request import DeleteSnapshotRequest
from huaweicloudsdkdws.v2.model.delete_snapshot_response import DeleteSnapshotResponse
from huaweicloudsdkdws.v2.model.detail import Detail
from huaweicloudsdkdws.v2.model.endpoints import Endpoints
from huaweicloudsdkdws.v2.model.failed_reason import FailedReason
from huaweicloudsdkdws.v2.model.list_cluster_details_request import ListClusterDetailsRequest
from huaweicloudsdkdws.v2.model.list_cluster_details_response import ListClusterDetailsResponse
from huaweicloudsdkdws.v2.model.list_clusters_request import ListClustersRequest
from huaweicloudsdkdws.v2.model.list_clusters_response import ListClustersResponse
from huaweicloudsdkdws.v2.model.list_node_types_request import ListNodeTypesRequest
from huaweicloudsdkdws.v2.model.list_node_types_response import ListNodeTypesResponse
from huaweicloudsdkdws.v2.model.list_snapshot_details_request import ListSnapshotDetailsRequest
from huaweicloudsdkdws.v2.model.list_snapshot_details_response import ListSnapshotDetailsResponse
from huaweicloudsdkdws.v2.model.list_snapshots_request import ListSnapshotsRequest
from huaweicloudsdkdws.v2.model.list_snapshots_response import ListSnapshotsResponse
from huaweicloudsdkdws.v2.model.maintain_window import MaintainWindow
from huaweicloudsdkdws.v2.model.node_types import NodeTypes
from huaweicloudsdkdws.v2.model.parameter_group import ParameterGroup
from huaweicloudsdkdws.v2.model.public_endpoints import PublicEndpoints
from huaweicloudsdkdws.v2.model.public_ip import PublicIp
from huaweicloudsdkdws.v2.model.reset_password_request import ResetPasswordRequest
from huaweicloudsdkdws.v2.model.reset_password_request_body import ResetPasswordRequestBody
from huaweicloudsdkdws.v2.model.reset_password_response import ResetPasswordResponse
from huaweicloudsdkdws.v2.model.resize_cluster_request import ResizeClusterRequest
from huaweicloudsdkdws.v2.model.resize_cluster_request_body import ResizeClusterRequestBody
from huaweicloudsdkdws.v2.model.resize_cluster_response import ResizeClusterResponse
from huaweicloudsdkdws.v2.model.resize_info import ResizeInfo
from huaweicloudsdkdws.v2.model.restart_cluster_request import RestartClusterRequest
from huaweicloudsdkdws.v2.model.restart_cluster_request_body import RestartClusterRequestBody
from huaweicloudsdkdws.v2.model.restart_cluster_response import RestartClusterResponse
from huaweicloudsdkdws.v2.model.restore import Restore
from huaweicloudsdkdws.v2.model.restore_cluster_request import RestoreClusterRequest
from huaweicloudsdkdws.v2.model.restore_cluster_request_body import RestoreClusterRequestBody
from huaweicloudsdkdws.v2.model.restore_cluster_response import RestoreClusterResponse
from huaweicloudsdkdws.v2.model.scale_out import ScaleOut
from huaweicloudsdkdws.v2.model.snapshot import Snapshot
from huaweicloudsdkdws.v2.model.snapshot_detail import SnapshotDetail
from huaweicloudsdkdws.v2.model.snapshot_resp import SnapshotResp
from huaweicloudsdkdws.v2.model.snapshots import Snapshots
from huaweicloudsdkdws.v2.model.tags import Tags
